==> jc-1.4.0.tar.gz: java/awt/color/ICC__5fProfileGray.h <==
// public class java.awt.color.ICC_ProfileGray

// class file dependencies
// @dep_class 7f6d2ca910e6237f java_awt_color_ICC__5fProfile
// @dep_class 980a8be0d72c7b2c java_awt_color_ICC__5fProfileGray
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_color_ICC__5fProfile

#include "java/awt/color/ICC__5fProfile.h"

#ifndef _JC_java_awt_color_ICC__5fProfileGray_H_
#define _JC_java_awt_color_ICC__5fProfileGray_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_color_ICC__5fProfileGray$sub_refs	_jc_java_awt_color_ICC__5fProfileGray$sub_refs;
typedef struct _jc_java_awt_color_ICC__5fProfileGray$sub_nonrefs	_jc_java_awt_color_ICC__5fProfileGray$sub_nonrefs;
typedef struct _jc_java_awt_color_ICC__5fProfileGray$refs	_jc_java_awt_color_ICC__5fProfileGray$refs;
typedef struct _jc_java_awt_color_ICC__5fProfileGray$nonrefs	_jc_java_awt_color_ICC__5fProfileGray$nonrefs;
typedef struct _jc_java_awt_color_ICC__5fProfileGray$object	_jc_java_awt_color_ICC__5fProfileGray$object;

typedef struct _jc_java_awt_color_ICC__5fProfileGray$fields_struct	_jc_java_awt_color_ICC__5fProfileGray$fields_struct;
typedef const struct _jc_java_awt_color_ICC__5fProfileGray$vmethods	_jc_java_awt_color_ICC__5fProfileGray$vmethods;
typedef const struct _jc_java_awt_color_ICC__5fProfileGray$vtable	_jc_java_awt_color_ICC__5fProfileGray$vtable;
typedef const struct _jc_java_awt_color_ICC__5fProfileGray$vtype	_jc_java_awt_color_ICC__5fProfileGray$vtype;

// Class fields structure
struct _jc_java_awt_color_ICC__5fProfileGray$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_color_ICC__5fProfileGray$fields_struct _jc_java_awt_color_ICC__5fProfileGray$class_fields;

// Constructors
extern void _jc_java_awt_color_ICC__5fProfileGray$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *, jint);
extern void _jc_java_awt_color_ICC__5fProfileGray$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *, struct _jc_byte_array *);

// Virtual methods
extern jfloat _jc_java_awt_color_ICC__5fProfileGray$method$getGamma$0fab0ddc74dd7c3b(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *);
extern _jc_float_array *_jc_java_awt_color_ICC__5fProfileGray$method$getMediaWhitePoint$04a03c9a4a91efe6(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *);
extern _jc_short_array *_jc_java_awt_color_ICC__5fProfileGray$method$getTRC$fd91da368e32ba4a(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_color_ICC__5fProfileGray$method_info$getGamma$0fab0ddc74dd7c3b;
extern _jc_method _jc_java_awt_color_ICC__5fProfileGray$method_info$getMediaWhitePoint$04a03c9a4a91efe6;
extern _jc_method _jc_java_awt_color_ICC__5fProfileGray$method_info$getTRC$fd91da368e32ba4a;

// Virtual methods structure
struct _jc_java_awt_color_ICC__5fProfileGray$vmethods {
	jfloat	(*getGamma$0fab0ddc74dd7c3b)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *);
	_jc_float_array	*(*getMediaWhitePoint$04a03c9a4a91efe6)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *);
	_jc_short_array	*(*getTRC$fd91da368e32ba4a)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *);
};

// Vtable
struct _jc_java_awt_color_ICC__5fProfileGray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_color_ICC__5fProfile$vmethods	java_awt_color_ICC__5fProfile;
	_jc_java_awt_color_ICC__5fProfileGray$vmethods	java_awt_color_ICC__5fProfileGray;
};

// Vtype
struct _jc_java_awt_color_ICC__5fProfileGray$vtype {
	_jc_type			type;
	_jc_java_awt_color_ICC__5fProfileGray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_color_ICC__5fProfileGray$sub_refs {
	_jc_float_array	*whitePoint;
};

// Reference instance fields (object)
struct _jc_java_awt_color_ICC__5fProfileGray$refs {
    _jc_java_awt_color_ICC__5fProfileGray$sub_refs	java_awt_color_ICC__5fProfileGray;
    _jc_java_awt_color_ICC__5fProfile$sub_refs	java_awt_color_ICC__5fProfile;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_color_ICC__5fProfileGray$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_color_ICC__5fProfileGray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_color_ICC__5fProfile$sub_nonrefs	java_awt_color_ICC__5fProfile;
    _jc_java_awt_color_ICC__5fProfileGray$sub_nonrefs	java_awt_color_ICC__5fProfileGray;
};

// Object instance structure
struct _jc_java_awt_color_ICC__5fProfileGray$object {
	_jc_java_awt_color_ICC__5fProfileGray$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_color_ICC__5fProfileGray$vtype	*vtype;
	_jc_java_awt_color_ICC__5fProfileGray$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_color_ICC__5fProfileGray$vtype _jc_java_awt_color_ICC__5fProfileGray$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_color_ICC__5fProfileGray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_color_ICC__5fProfileGray$class_object;

#endif	/* _JC_java_awt_color_ICC__5fProfileGray_H_ */

==> jc-1.4.6.tar.gz: java/awt/color/ICC__5fProfileGray.h <==
// public class java.awt.color.ICC_ProfileGray

// class file dependencies
// @dep_class 7f6d2ca910e6237f java_awt_color_ICC__5fProfile
// @dep_class 980a8be0d72c7b2c java_awt_color_ICC__5fProfileGray
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_color_ICC__5fProfile

#include "java/awt/color/ICC__5fProfile.h"

#ifndef _JC_java_awt_color_ICC__5fProfileGray_H_
#define _JC_java_awt_color_ICC__5fProfileGray_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_color_ICC__5fProfileGray$sub_refs	_jc_java_awt_color_ICC__5fProfileGray$sub_refs;
typedef struct _jc_java_awt_color_ICC__5fProfileGray$sub_nonrefs	_jc_java_awt_color_ICC__5fProfileGray$sub_nonrefs;
typedef struct _jc_java_awt_color_ICC__5fProfileGray$refs	_jc_java_awt_color_ICC__5fProfileGray$refs;
typedef struct _jc_java_awt_color_ICC__5fProfileGray$nonrefs	_jc_java_awt_color_ICC__5fProfileGray$nonrefs;
typedef struct _jc_java_awt_color_ICC__5fProfileGray$object	_jc_java_awt_color_ICC__5fProfileGray$object;

typedef struct _jc_java_awt_color_ICC__5fProfileGray$fields_struct	_jc_java_awt_color_ICC__5fProfileGray$fields_struct;
typedef const struct _jc_java_awt_color_ICC__5fProfileGray$vmethods	_jc_java_awt_color_ICC__5fProfileGray$vmethods;
typedef const struct _jc_java_awt_color_ICC__5fProfileGray$vtable	_jc_java_awt_color_ICC__5fProfileGray$vtable;
typedef const struct _jc_java_awt_color_ICC__5fProfileGray$vtype	_jc_java_awt_color_ICC__5fProfileGray$vtype;

// Class fields structure
struct _jc_java_awt_color_ICC__5fProfileGray$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_color_ICC__5fProfileGray$fields_struct _jc_java_awt_color_ICC__5fProfileGray$class_fields;

// Constructors
extern void _jc_java_awt_color_ICC__5fProfileGray$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_color_ICC__5fProfileGray$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jfloat _jc_java_awt_color_ICC__5fProfileGray$method$getGamma$0fab0ddc74dd7c3b(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_java_awt_color_ICC__5fProfileGray$method$getMediaWhitePoint$04a03c9a4a91efe6(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *) _JC_JCNI_ATTR;
extern _jc_short_array *_jc_java_awt_color_ICC__5fProfileGray$method$getTRC$fd91da368e32ba4a(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_color_ICC__5fProfileGray$method_info$getGamma$0fab0ddc74dd7c3b;
extern _jc_method _jc_java_awt_color_ICC__5fProfileGray$method_info$getMediaWhitePoint$04a03c9a4a91efe6;
extern _jc_method _jc_java_awt_color_ICC__5fProfileGray$method_info$getTRC$fd91da368e32ba4a;

// Virtual methods structure
struct _jc_java_awt_color_ICC__5fProfileGray$vmethods {
	jfloat	(*getGamma$0fab0ddc74dd7c3b)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *) _JC_JCNI_ATTR;
	_jc_float_array	*(*getMediaWhitePoint$04a03c9a4a91efe6)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *) _JC_JCNI_ATTR;
	_jc_short_array	*(*getTRC$fd91da368e32ba4a)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileGray$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_color_ICC__5fProfileGray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_color_ICC__5fProfile$vmethods	java_awt_color_ICC__5fProfile;
	_jc_java_awt_color_ICC__5fProfileGray$vmethods	java_awt_color_ICC__5fProfileGray;
};

// Vtype
struct _jc_java_awt_color_ICC__5fProfileGray$vtype {
	_jc_type			type;
	_jc_java_awt_color_ICC__5fProfileGray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_color_ICC__5fProfileGray$sub_refs {
	_jc_float_array	*whitePoint;
};

// Reference instance fields (object)
struct _jc_java_awt_color_ICC__5fProfileGray$refs {
    _jc_java_awt_color_ICC__5fProfileGray$sub_refs	java_awt_color_ICC__5fProfileGray;
    _jc_java_awt_color_ICC__5fProfile$sub_refs	java_awt_color_ICC__5fProfile;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_color_ICC__5fProfileGray$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_color_ICC__5fProfileGray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_color_ICC__5fProfile$sub_nonrefs	java_awt_color_ICC__5fProfile;
    _jc_java_awt_color_ICC__5fProfileGray$sub_nonrefs	java_awt_color_ICC__5fProfileGray;
};

// Object instance structure
struct _jc_java_awt_color_ICC__5fProfileGray$object {
	_jc_java_awt_color_ICC__5fProfileGray$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_color_ICC__5fProfileGray$vtype	*vtype;
	_jc_java_awt_color_ICC__5fProfileGray$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_color_ICC__5fProfileGray$vtype _jc_java_awt_color_ICC__5fProfileGray$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_color_ICC__5fProfileGray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_color_ICC__5fProfileGray$class_object;

#endif	/* _JC_java_awt_color_ICC__5fProfileGray_H_ */
